<div class="admonition note">
  <p class="admonition-title">Note</p>
  <p>This section is incomplete and will soon be updated.
</p>
</div>

The AEAs currently use the addresses associated with their private-public key pairs to identify themselves.

To learn how to generate a private-public key pair check out <a href="../cli-commands">this section</a>.
